.. module:: enaml.widgets.file_dialog_ex

============================
enaml.widgets.file_dialog_ex
============================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    FileDialogEx


.. autoclass:: FileDialogEx
